@@ -1,5 +1,8 @@
+import uuid
+
 from django.conf import settings
 from django.contrib import admin, messages
+from django.core.exceptions import ValidationError
 from django.http import HttpResponse
 from django.contrib.auth.admin import UserAdmin
 from django.contrib.auth import get_user_model
@@ -95,12 +98,12 @@ class QRCodeAdmin(admin.ModelAdmin):
 
     def scan_view(self, request):
         if request.method == 'POST':
-            uuid = request.POST['short_uuid']
+            short_uuid = request.POST['short_uuid']
             try:
-                code = QRCode.objects.get(uuid)
-                return redirect('admin:qrtoolkit_core_qrcode_change', kwargs={'object_id': code.pk})
+                code = _get_qr_code(short_uuid)
+                return redirect('admin:qrtoolkit_core_qrcode_change', object_id=code.pk)
             except QRCode.DoesNotExist:
-                self.message_user(request, f'Qr code with uuid {uuid} not found.', level=messages.WARNING)
+                self.message_user(request, f'Qr code with uuid {short_uuid} not found.', level=messages.WARNING)
 
         context = dict(
             # Include common variables for rendering the admin template.
@@ -150,3 +153,13 @@ class DepartmentAdmin(admin.ModelAdmin):
 admin.site.site_header = 'Qr Gent Administration'
 admin.site.site_title = 'Qr Gent admin'
 admin.site.site_url = settings.API_URL
+
+
+def _get_qr_code(short_uuid):
+    try:
+        short_uuid = uuid.UUID(short_uuid)
+        # short_uuid is a valid uuid object
+        return QRCode.objects.get(uuid=short_uuid)
+    except ValueError:
+        # short_uuid is not a valid uuid object
+        return QRCode.objects.get(short_uuid=short_uuid)
